==> pmml-springboot-example-1.8.0.Final-sources.jar: testscorecard/simplescorecard/SimpleScorecard.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package testscorecard.simplescorecard;

import java.util.Collections;
import org.kie.pmml.commons.model.KiePMMLOutputField;
import org.kie.pmml.api.enums.PMML_MODEL;
import org.kie.pmml.models.drools.scorecard.model.KiePMMLScorecardModel;

public class SimpleScorecard extends KiePMMLScorecardModel {

    public SimpleScorecard() {
        super("SimpleScorecard", Collections.emptyList());
        targetField = "score";
        pmmlMODEL = org.kie.pmml.api.enums.PMML_MODEL.SCORECARD_MODEL;
        miningFunction = org.kie.pmml.api.enums.MINING_FUNCTION.REGRESSION;
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Score", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 1", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 2", Collections.emptyList()).withRank(2).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        fieldTypeMap.put("score", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "SCORE"));
        fieldTypeMap.put("input2", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "INPUT2"));
        fieldTypeMap.put("input1", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "INPUT1"));
        miningFields.add(new org.kie.pmml.api.models.MiningField("input1", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("input2", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("score", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.TARGET, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Score", org.kie.pmml.api.enums.OP_TYPE.CONTINUOUS, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE, null));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Reason Code 1", org.kie.pmml.api.enums.OP_TYPE.CATEGORICAL, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE, null));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Reason Code 2", org.kie.pmml.api.enums.OP_TYPE.CATEGORICAL, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE, null));
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Score", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 1", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 2", Collections.emptyList()).withRank(2).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
    }

    @Override
    public String getKModulePackageName() {
        return "testscorecard.simplescorecard";
    }
}

==> pmml-springboot-example-1.9.1.Final-sources.jar: testscorecard/simplescorecard/SimpleScorecard.java <==
package testscorecard.simplescorecard;

import java.util.Arrays;
import java.util.Collections;
import org.kie.pmml.commons.model.KiePMMLOutputField;
import org.kie.pmml.commons.model.expressions.*;
import org.kie.pmml.commons.transformations.*;
import org.kie.pmml.api.enums.PMML_MODEL;
import org.kie.pmml.models.drools.scorecard.model.KiePMMLScorecardModel;

public class SimpleScorecard extends KiePMMLScorecardModel {

    public SimpleScorecard() {
        super("SimpleScorecard", Collections.emptyList());
        targetField = "score";
        pmmlMODEL = org.kie.pmml.api.enums.PMML_MODEL.SCORECARD_MODEL;
        miningFunction = org.kie.pmml.api.enums.MINING_FUNCTION.REGRESSION;
        transformationDictionary = null;
        localTransformations = null;
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Score", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 1", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 2", Collections.emptyList()).withRank(2).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        fieldTypeMap.put("score", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "SCORE"));
        fieldTypeMap.put("input2", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "INPUT2"));
        fieldTypeMap.put("input1", new org.kie.pmml.models.drools.tuples.KiePMMLOriginalTypeGeneratedType("double", "INPUT1"));
        miningFields.add(new org.kie.pmml.api.models.MiningField("input1", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("input2", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("score", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.TARGET, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Score", org.kie.pmml.api.enums.OP_TYPE.CONTINUOUS, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE, null));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Reason Code 1", org.kie.pmml.api.enums.OP_TYPE.CATEGORICAL, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE, null));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Reason Code 2", org.kie.pmml.api.enums.OP_TYPE.CATEGORICAL, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE, null));
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Score", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 1", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Reason Code 2", Collections.emptyList()).withRank(2).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.REASON_CODE).build());
    }

    @Override
    public String getKModulePackageName() {
        return "testscorecard.simplescorecard";
    }
}
